//+----------------------------------------------------------------------+
//|                                      MACD_Overlay & ALerts & mtf.mq4 |
//+----------------------------------------------------------------------+
#property indicator_chart_window
#property indicator_buffers 8

#property indicator_color1 clrLimeGreen
#property indicator_color2 clrLimeGreen
#property indicator_color3 clrLimeGreen
#property indicator_color4 clrLimeGreen
#property indicator_color5 clrPaleVioletRed
#property indicator_color6 clrPaleVioletRed
#property indicator_color7 clrPaleVioletRed
#property indicator_color8 clrPaleVioletRed
#property indicator_width1 1
#property indicator_width2 1
#property indicator_width3 2
#property indicator_width4 2
#property indicator_width5 1
#property indicator_width6 1
#property indicator_width7 2
#property indicator_width8 2

#property description "Forex-station.com\n\n"
#property description "Colored bars depending on MACD Oscillator.\n\n1Available modes:\n\n2) Compare MACD and Signal Lines\n\n3) MACD above or below Zero Line\n\n4) Compare Current MACD value with Previous MACD value"

enum e_method{ MACD_Signal=1, MACD_Zero_Line=2, MACD_Compare=3 };

extern ENUM_TIMEFRAMES TimeFrame=PERIOD_CURRENT;
extern int      Fast_EMA    = 12;
extern int      Slow_EMA    = 26;
extern int      Signal_Line = 9;
extern e_method Method      = MACD_Signal;
extern bool  alertsOn        = false;
extern bool  alertsOnCurrent = true;
extern bool  alertsMessage   = true;
extern bool  alertsSound     = false;
extern bool  alertsEmail     = false;

double Up_High[];
double Up_Low[];
double Up_Open[];
double Up_Close[];
double Dn_High[];
double Dn_Low[];
double Dn_Open[];
double Dn_Close[];

double MACD[];
double Signal[],trend[];

int Bullish = 1;
int Bearish = -1;
int Neutral = 0;

int init(){
 
   IndicatorShortName("MACD Overlay ");
   IndicatorBuffers(11);
   
   SetIndexBuffer(0,Up_High);
   SetIndexBuffer(1,Up_Low);
   SetIndexBuffer(2,Up_Open);
   SetIndexBuffer(3,Up_Close);
   SetIndexBuffer(4,Dn_High);
   SetIndexBuffer(5,Dn_Low);
   SetIndexBuffer(6,Dn_Open);
   SetIndexBuffer(7,Dn_Close);
   SetIndexBuffer(8,MACD);
   SetIndexBuffer(9,Signal);
   SetIndexBuffer(10,trend);
   
   for (int i=0; i<8; i++) SetIndexStyle(i,DRAW_HISTOGRAM);
      TimeFrame = MathMax(TimeFrame,_Period);

   return(0);
   
}

int start()
{   
   int counted_bars = IndicatorCounted();
      if(counted_bars<0) return(-1);
      if(counted_bars>0) counted_bars--;
         int limit = MathMin(MathMax(Bars-counted_bars,2*TimeFrame/_Period),Bars-1);


   for(int i=limit; i>=0 && !_StopFlag; i--)
   {
      int y = iBarShift(NULL,TimeFrame,Time[i]);
      Up_High[i]  = EMPTY_VALUE;
      Up_Low[i]   = EMPTY_VALUE;
      Up_Open[i]  = EMPTY_VALUE;
      Up_Close[i] = EMPTY_VALUE;
      Dn_High[i]  = EMPTY_VALUE;
      Dn_Low[i]   = EMPTY_VALUE;
      Dn_Open[i]  = EMPTY_VALUE;
      Dn_Close[i] = EMPTY_VALUE;
   
      MACD[i]   = iMACD(NULL,TimeFrame,Fast_EMA,Slow_EMA,Signal_Line,PRICE_CLOSE,MODE_MAIN,y);
      Signal[i] = iMACD(NULL,TimeFrame,Fast_EMA,Slow_EMA,Signal_Line,PRICE_CLOSE,MODE_SIGNAL,y);
      
      trend[i] =  ColorCandle(MACD[i], Signal[i], iMACD(NULL,TimeFrame,Fast_EMA,Slow_EMA,Signal_Line,PRICE_CLOSE,MODE_MAIN,y+1));
      if(trend[i]>0){
         
         Up_High[i]  = iHigh(NULL,0,i);
         Up_Low[i]   = iLow(NULL,0,i);  
         Up_Open[i]  = iOpen(NULL,0,i);
         Up_Close[i] = iClose(NULL,0,i);  
      
      }
      if(trend[i]<0)
      {
         Dn_High[i]  = iHigh(NULL,0,i);
         Dn_Low[i]   = iLow(NULL,0,i);  
         Dn_Open[i]  = iOpen(NULL,0,i);
         Dn_Close[i] = iClose(NULL,0,i);
      
      }

   }
   if (alertsOn)
   {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1;
      if (trend[whichBar] != trend[whichBar+1])
         if (trend[whichBar] == 1)
               doAlert(" bullish");
         else  doAlert(" bearish");
   }
   return(0);

}

int ColorCandle(double macd_value, double signal_value, double previous_macd){
 
   if (Method==1){
   
      if (macd_value >= signal_value)
         return(Bullish);
      else
         return (Bearish);
         
   }
   else if (Method==2){
      
      if (macd_value >= 0)
         return(Bullish);
      else
         return (Bearish);
      
   }
   else{
   
      if (macd_value >= previous_macd)
         return(Bullish);
      else
         return (Bearish);
   
   }

}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+  
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," MACD overlay trend changed to ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsEmail)   SendMail(StringConcatenate(Symbol(),"MACD overlay "),message);
             if (alertsSound)   PlaySound("alert2.wav");
      }
}
